*********
Changelog
*********

v1.0.0 (2024-08-23)
===================
First complete version of PySchematron. See the readme for the functionality and limitations.

v0.1.0 (2022-09-10)
===================
First version.
